/**
 * @semantic-ui/core v0.12.4
 * Semantic empowers designers and developers by creating a shared vocabulary for UI.
 *
 * @license MIT
 * @copyright (c) 2025 Jack Lukic <jack@semantic-ui.com>
 * @homepage http://next.semantic-ui.com
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

// src/components/input/input.js
import { defineComponent } from "https://cdn.jsdelivr.net/npm/@semantic-ui/component@0.12.4/dist/index.min.js";

// packages/utils/src/functions.js
var debounce = (fn, options) => {
  if (typeof options == "number") {
    options = { delay: options };
  }
  const {
    delay = 200,
    immediate = false
  } = options;
  let timeout;
  let callbackCalled = false;
  function debounced(...args) {
    const later = () => {
      timeout = null;
      if (!immediate) {
        fn.apply(this, args);
      }
      callbackCalled = false;
    };
    const callNow = immediate && !timeout;
    clearTimeout(timeout);
    timeout = setTimeout(later, delay);
    if (callNow && !callbackCalled) {
      callbackCalled = true;
      fn.apply(this, args);
    }
  }
  debounced.cancel = () => {
    clearTimeout(timeout);
    timeout = null;
    callbackCalled = false;
  };
  return debounced;
};

// packages/utils/src/colors.js
var GAMMA_EXPONENT = 1 / 2.4;

// src/components/input/specs/input-component.json
var input_component_default = {
  tagName: "ui-input",
  content: [
    "placeholder",
    "icon",
    "label"
  ],
  contentAttributes: [
    "placeholder",
    "icon",
    "label"
  ],
  types: [
    "search"
  ],
  variations: [
    "fluid",
    "size"
  ],
  settings: [
    "name",
    "type",
    "debounced",
    "debounce-interval",
    "clearable",
    "value"
  ],
  attributes: [
    "placeholder",
    "icon",
    "label",
    "search",
    "fluid",
    "size",
    "name",
    "type",
    "debounced",
    "debounce-interval",
    "clearable",
    "value"
  ],
  optionAttributes: {
    mini: "size",
    tiny: "size",
    small: "size",
    medium: "size",
    large: "size",
    big: "size",
    huge: "size",
    massive: "size"
  },
  propertyTypes: {
    placeholder: "string",
    icon: "string",
    label: "string",
    search: "boolean",
    fluid: "boolean",
    size: "string",
    name: "string",
    type: "string",
    debounced: "boolean",
    clearable: "string",
    value: "string"
  },
  allowedValues: {
    size: [
      "mini",
      "tiny",
      "small",
      "medium",
      "large",
      "big",
      "huge",
      "massive"
    ]
  },
  attributeClasses: [
    "icon",
    "label"
  ],
  defaultValues: {
    name: "",
    type: "text",
    debounced: false,
    "debounce-interval": 150,
    clearable: "",
    value: ""
  }
};

// src/components/input/input.html?raw
var input_default = '<div class="{ui}{classMap getStateClasses}input" part="input">\n  <input type="{type}" placeholder="{placeholder}" name={name} value={value} part="input-field">\n  {#if icon}\n    {#if isClearable}\n      <ui-icon icon="x" link class="clickable icon" part="icon"></ui-icon>\n    {else}\n      <ui-icon icon={getIcon} class="icon" part="icon"></ui-icon>\n    {/if}\n  {/if}\n  {#if label}\n    <div class="label" part="label">\n      {label}\n    </div>\n  {/if}\n</div>\n';

// src/components/input/input-bundle.css?raw
var input_bundle_default = '/**\n  ---DO NOT EDIT THIS FILE DIRECTLY---\n  This CSS file was concatenated from files listed in the css/ folder as part of a build process\n  This is to allow for js import with @import links which will not be followed\n**/\n\n/* src/components/input/css/definition/content/input.css */\n@layer input.definition.content.input {\n  * {\n    box-sizing: border-box;\n  }\n  .input {\n    cursor: text;\n    display: inline-flex;\n    position: relative;\n    font-style: normal;\n    font-weight: var(--input-font-weight);\n    font-family: var(--input-font-family);\n    line-height: var(--input-line-height);\n    color: var(--input-text-color);\n    background: var(--input-background);\n    border: var(--input-border);\n    border-radius: var(--input-border-radius);\n    transition: var(--input-transition);\n    box-shadow: var(--input-box-shadow);\n    gap: var(--input-item-spacing);\n    text-align: var(--input-text-align);\n    align-items: center;\n  }\n  .input input {\n    width: var(--input-width);\n    padding: var(--input-padding);\n    background-color: transparent;\n    margin: 0em;\n    border-radius: inherit;\n    outline: none;\n    max-width: 100%;\n    flex: 1 0 auto;\n    text-align: inherit;\n    font-size: inherit;\n    font-family: inherit;\n    color: inherit;\n    border: none;\n    -webkit-tap-highlight-color: rgba(255, 255, 255, 0);\n    z-index: var(--page-layer-1);\n  }\n  .input input::placeholder {\n    color: var(--input-placeholder-color);\n  }\n  .input .icon {\n    position: absolute;\n    z-index: var(--input-icon-index);\n    right: var(--input-icon-right);\n    width: var(--input-icon-width);\n    pointer-events: none;\n    margin: 0rem;\n  }\n  .input .icon.clickable {\n    pointer-events: auto;\n    cursor: pointer;\n  }\n  .input .icon + .label {\n    right: var(--input-label-with-icon-right);\n  }\n  .input .label {\n    position: absolute;\n    z-index: var(--page-layer-2);\n    pointer-events: none;\n    right: var(--input-label-right);\n    display: inline-block;\n    text-wrap: nowrap;\n    margin-left: auto;\n    line-height: 1;\n    font-weight: var(--input-label-font-weight);\n    color: var(--input-label-color);\n    font-size: var(--input-label-font-size);\n    padding: var(--input-label-padding);\n    border: var(--input-label-border);\n    border-radius: var(--input-label-border-radius);\n  }\n}\n\n/* src/components/input/css/definition/types/search.css */\n@layer input.definition.types.search {\n  .search.input {\n    border-radius: var(--circular-radius);\n  }\n}\n\n/* src/components/input/css/definition/states/focused.css */\n@layer input.definition.states.focus {\n  .input.focus,\n  .input:focus-within {\n    border-color: var(--input-focused-border-color);\n    background: var(--input-focused-background);\n    color: var(--input-focused-color);\n    box-shadow: var(--input-focused-box-shadow);\n  }\n  .input:focus-within > input::placeholder,\n  .input.focus > input::placeholder {\n    color: var(--input-placeholder-focused-color);\n  }\n}\n\n/* src/components/input/css/definition/states/loading.css */\n@layer input.definition.states.loading {\n  .loading.input:not(.icon) {\n    position: relative;\n    cursor: default;\n    text-shadow: none !important;\n    color: transparent !important;\n    opacity: var(--input-loading-opacity);\n    pointer-events: auto;\n    transition: var(--input-loading-transition);\n  }\n  .loading.icon.input .icon {\n    position: relative;\n    color: transparent !important;\n  }\n  .loading.icon.input > .icon:before,\n  .loading.input:not(.icon)::before {\n    position: absolute;\n    content: "";\n    top: 50%;\n    left: 50%;\n    margin: var(--loader-margin);\n    width: var(--loader-size);\n    height: var(--loader-size);\n    border-radius: var(--circular-radius);\n    border: var(--loader-line-width) solid var(--loader-fill-color);\n  }\n  .loading.icon.input > .icon:after,\n  .loading.input:not(.icon)::after {\n    position: absolute;\n    content: "";\n    top: 50%;\n    left: 50%;\n    margin: var(--loader-margin);\n    width: var(--loader-size);\n    height: var(--loader-size);\n    animation: input-spin var(--loader-speed) linear;\n    animation-iteration-count: infinite;\n    border-radius: var(--circular-radius);\n    border-color: var(--loader-line-color) transparent transparent;\n    border-style: solid;\n    border-width: var(--loader-line-width);\n    box-shadow: 0px 0px 0px 1px transparent;\n  }\n  @keyframes input-spin {\n    from {\n      transform: rotate(0deg);\n    }\n    to {\n      transform: rotate(360deg);\n    }\n  }\n  .loading.input.inverted .icon:before,\n  .loading.input.inverted:before {\n    border-color: var(--inverted-loader-fill-color);\n  }\n  .loading.input.inverted .icon:after,\n  .loading.input.inverted:after {\n    border-top-color: var(--inverted-loader-line-color);\n  }\n}\n\n/* src/components/input/css/definition/states/disabled.css */\n@layer input.definition.states.disabled {\n  .disabled.input,\n  .disabled.input:hover,\n  .disabled.active.input {\n    cursor: var(--input-disabled-cursor);\n    opacity: var(--input-disabled-opacity) !important;\n    color: var(--input-disabled-color);\n    background-color: var(--input-disabled-background-color) !important;\n    background-image: var(--input-disabled-background-image) !important;\n    box-shadow: var(--input-disabled-box-shadow) !important;\n  }\n  ui-input[disabled] {\n    cursor: var(--input-disabled-cursor);\n    pointer-events: none !important;\n  }\n  .clickable-disabled.input {\n    pointer-events: auto !important;\n    cursor: var(--input-clickable-disabled-cursor) !important;\n  }\n  .clickable-disabled.input:active {\n    box-shadow: var(--input-pressed-box-shadow) !important;\n  }\n  ui-input[clickable-disabled] {\n    pointer-events: auto !important;\n    cursor: var(--input-clickable-disabled-cursor) !important;\n  }\n}\n\n/* src/components/input/css/definition/variations/sizing.css */\n@layer input.definition.variations.sizing {\n  .mini {\n    font-size: var(--input-mini);\n  }\n  .tiny {\n    font-size: var(--input-tiny);\n  }\n  .small {\n    font-size: var(--input-small);\n  }\n  :host {\n    font-size: var(--input-medium);\n  }\n  .large {\n    font-size: var(--input-large);\n  }\n  .big {\n    font-size: var(--input-big);\n  }\n  .huge {\n    font-size: var(--input-huge);\n  }\n  .massive {\n    font-size: var(--input-massive);\n  }\n}\n\n/* src/components/input/css/definition/variations/fluid.css */\n@layer input.definition.variations.fluid {\n  .fluid {\n    display: flex;\n    flex-grow: 1;\n    max-width: 100%;\n  }\n  .fluid input {\n    width: auto;\n  }\n}\n\n/* src/components/input/css/definition/input-definition.css */\n\n/* src/components/input/css/theme/content/input-variables.css */\n@layer input.theme.content.input {\n  :host {\n    --input-background: var(--inverted-100);\n    --input-width: 12em;\n    --input-font-family: var(--page-font);\n    --input-font-weight: var(--normal);\n    --input-text-color: var(--text-color);\n    --input-line-height: var(--relative-17px);\n    --input-text-align: left;\n    --input-box-shadow: var(--subtle-inset-shadow);\n    --input-border: var(--border);\n    --input-border-radius: var(--border-radius);\n    --input-item-spacing: 5px;\n    --input-placeholder-color: var(--standard-15);\n    --input-placeholder-focused-color: var(--standard-20);\n    --input-transition: box-shadow var(--duration) var(--easing), border-color var(--duration) var(--easing) ;\n    --input-icon-right: var(--input-horizontal-padding);\n    --input-icon-width: 1em;\n    --input-icon-index: var(--page-layer-2);\n    --input-label-right: var(--input-horizontal-padding);\n    --input-label-font-size: var(--relative-11px);\n    --input-label-font-weight: var(--bold);\n    --input-label-padding: var(--relative-2px) var(--relative-3px);\n    --input-label-color: var(--standard-20);\n    --input-label-border: var(--border);\n    --input-label-border-radius: var(--border-radius);\n    --input-label-with-icon-right: calc( 1em + var(--input-icon-width) + var(--input-icon-right) );\n  }\n}\n\n/* src/components/input/css/theme/types/search-variables.css */\n@layer input.theme.types.search {\n  :host {\n    --inputSearchBorderRadius: var(--circular-radius);\n  }\n}\n\n/* src/components/input/css/theme/states/disabled-variables.css */\n@layer input.theme.states.disabled {\n  :host {\n    --input-disabled-cursor: default;\n    --input-disabled-opacity: 1;\n    --input-disabled-background-color: #FFFFFF;\n    --input-disabled-background-image: var(--button-background-image);\n    --input-disabled-border-box-shadow: 0px 0px 0px var(--button-border-width) rgba(0, 0, 0, 0.1) inset;\n    --input-disabled-shadow-box-shadow: 0px 2px 3px rgba(0, 0, 0, 0.04);\n    --input-disabled-color: var(--black-20);\n    --input-disabled-box-shadow:\n      var(--button-sharpen-box-shadow),\n      var(--button-disabled-border-box-shadow),\n      var(--button-disabled-shadow-box-shadow) ;\n    --input-clickable-disabled-cursor: not-allowed;\n  }\n}\n\n/* src/components/input/css/theme/states/loading-variables.css */\n@layer input.theme.states.loading {\n  :host {\n    --button-loading-icon-duration: 2s;\n    --button-loading-opacity: 1;\n    --button-loading-transition: opacity var(--button-transition-duration) var(--button-transition-easing) ;\n  }\n}\n\n/* src/components/input/css/theme/states/focused-variables.css */\n@layer input.theme.states.focused {\n  :host {\n    --input-focused-border-color: var(--form-focused-border-color);\n    --input-focused-background: var(--input-background);\n    --input-focused-color: var(--input-text-color);\n    --input-focused-placeholder-color: var(--white-15);\n    --input-focused-box-shadow: none;\n    --input-placeholder-focused-color: var(--standard-20);\n  }\n}\n\n/* src/components/input/css/theme/variations/aligned-variables.css */\n@layer input.theme.variations.aligned {\n  :host {\n  }\n}\n\n/* src/components/input/css/theme/variations/sizing-variables.css */\n@layer input.theme.variations.sizing {\n  :host {\n    --input-mini: var(--mini);\n    --input-tiny: var(--tiny);\n    --input-small: var(--small);\n    --input-medium: inherit;\n    --input-large: var(--large);\n    --input-big: var(--big);\n    --input-huge: var(--huge);\n    --input-massive: var(--massive);\n  }\n}\n\n/* src/components/input/css/theme/input-theme.css */\n\n/* src/components/input/css/input.css */\n';

// src/components/input/input.js
var defaultState = {
  focused: false
};
var createComponent = ({ $, el, self, state, dispatchEvent, settings }) => ({
  initialize() {
    if (settings.search) {
      self.configureSearch();
    }
  },
  // allow default styling for search
  configureSearch() {
    settings.placeholder = settings.placeholder || "Search...";
    settings.icon = settings.icon || "search";
    settings.clearable = settings.clearable ?? true;
    settings.debounce = true;
  },
  hasValue() {
    return (settings.value || "").length > 0;
  },
  isClearable() {
    return settings.clearable && self.hasValue();
  },
  getStateClasses() {
    return {
      focus: state.focused.get()
    };
  },
  getIcon() {
    if (settings.clearable && self.hasValue()) {
      return "x";
    }
    return settings.icon;
  },
  setValue(value) {
    el.value = value;
    $("input").val(value);
    dispatchEvent("input", { value });
  },
  setValueDebounced: debounce((value) => {
    self.setValue(value);
  }, { delay: settings.debounceInterval })
});
var events = {
  "click ui-icon"({ $, self }) {
    if (self.isClearable()) {
      self.setValue("");
    }
  },
  "focus input"({ state }) {
    state.focused.set(true);
  },
  "blur input"({ state, dispatchEvent, el }) {
    state.focused.set(false);
    dispatchEvent("change", { value: el.value });
  },
  "input input"({ el, self, value, settings }) {
    if (settings.debounced) {
      self.setValueDebounced(value);
    } else {
      self.setValue(value);
    }
  }
};
var UIInput = defineComponent({
  tagName: "ui-input",
  componentSpec: input_component_default,
  template: input_default,
  css: input_bundle_default,
  createComponent,
  events,
  defaultState
});
export {
  UIInput
};
//# sourceMappingURL=input.js.map
